@@ -85,6 +85,7 @@ class IntegrationMaterialSocialCards(IntegrationMaterialThemeBase):
 
         # if enabled, save some config elements
         if self.IS_ENABLED:
+            self.mkdocs_use_directory_urls = mkdocs_config.use_directory_urls
             self.mkdocs_site_url = mkdocs_config.site_url
             self.mkdocs_site_build_dir = mkdocs_config.site_dir
             self.social_cards_dir = self.get_social_cards_dir(
@@ -99,10 +100,6 @@ class IntegrationMaterialSocialCards(IntegrationMaterialThemeBase):
 
             self.load_cache_cards_manifest()
 
-            # store some attributes used to compute social card hash
-            self.site_name = mkdocs_config.site_name
-            self.site_description = mkdocs_config.site_description or ""
-
     def is_social_plugin_enabled_mkdocs(
         self, mkdocs_config: MkDocsConfig | None = None
     ) -> bool:
@@ -378,12 +375,28 @@ class IntegrationMaterialSocialCards(IntegrationMaterialThemeBase):
         if mkdocs_site_url is None and self.mkdocs_site_url:
             mkdocs_site_url = self.mkdocs_site_url
 
-        # As of mkdocs-material 9.6.5, social cards are always stored in the
-        # matching src path in the build folder, regardless of the page type.
-        page_social_card = (
-            f"{mkdocs_site_url}{self.social_cards_dir}/"
-            f"{Path(mkdocs_page.src_uri).with_suffix('.png')}"
-        )
+        # if page is a blog post
+        if (
+            self.integration_material_blog.IS_BLOG_PLUGIN_ENABLED
+            and self.integration_material_blog.is_page_a_blog_post(mkdocs_page)
+        ):
+            if self.mkdocs_use_directory_urls:
+                # see: https://github.com/Guts/mkdocs-rss-plugin/issues/319
+                page_social_card = (
+                    f"{mkdocs_site_url}{self.social_cards_dir}/"
+                    f"{Path(mkdocs_page.dest_uri).parent.with_suffix('.png')}"
+                )
+            else:
+                page_social_card = (
+                    f"{mkdocs_site_url}{self.social_cards_dir}/"
+                    f"{Path(mkdocs_page.dest_uri).with_suffix('.png')}"
+                )
+        else:
+            page_social_card = (
+                f"{mkdocs_site_url}{self.social_cards_dir}/"
+                f"{Path(mkdocs_page.src_uri).with_suffix('.png')}"
+            )
+
         logger.debug(f"Use social card url: {page_social_card}")
 
         return page_social_card
