@@ -9,10 +9,10 @@ import json
 from copy import deepcopy
 from dataclasses import asdict
 from datetime import datetime
-from email.utils import formatdate
+from email.utils import format_datetime, formatdate
 from pathlib import Path
 from re import compile as re_compile
-from typing import Literal, Optional
+from typing import Literal
 
 # 3rd party
 from jinja2 import Environment, FileSystemLoader, select_autoescape
@@ -24,7 +24,7 @@ from mkdocs.structure.pages import Page
 from mkdocs.utils import get_build_timestamp
 
 # package modules
-from mkdocs_rss_plugin.__about__ import __title__, __uri__, __version__
+from mkdocs_rss_plugin.__about__ import __title__, __version__
 from mkdocs_rss_plugin.config import RssPluginConfig
 from mkdocs_rss_plugin.constants import (
     DEFAULT_TEMPLATE_FILENAME,
@@ -37,7 +37,7 @@ from mkdocs_rss_plugin.integrations.theme_material_blog_plugin import (
 from mkdocs_rss_plugin.integrations.theme_material_social_plugin import (
     IntegrationMaterialSocialCards,
 )
-from mkdocs_rss_plugin.models import PageInformation, RssFeedBase
+from mkdocs_rss_plugin.models import MkdocsPageSubset, PageInformation, RssFeedBase
 from mkdocs_rss_plugin.util import Util
 
 # ############################################################################
@@ -265,7 +265,7 @@ class GitRssPlugin(BasePlugin[RssPluginConfig]):
     @event_priority(priority=-75)
     def on_page_content(
         self, html: str, page: Page, config: MkDocsConfig, files: Files
-    ) -> Optional[str]:
+    ) -> str | None:
         """The page_content event is called after the Markdown text is rendered to HTML
             (but before being passed to a template) and can be used to alter the HTML
             body of the page.
@@ -331,6 +331,7 @@ class GitRssPlugin(BasePlugin[RssPluginConfig]):
                 categories=self.util.get_categories_from_meta(
                     in_page=page, categories_labels=self.config.categories
                 ),
+                comments_url=page_url_comments,
                 created=page_dates[0],
                 description=self.util.get_description_or_abstract(
                     in_page=page,
@@ -338,15 +339,11 @@ class GitRssPlugin(BasePlugin[RssPluginConfig]):
                     abstract_delimiter=self.config.abstract_delimiter,
                 ),
                 guid=page.canonical_url,
-                image=self.util.get_image(
-                    in_page=page,
-                    # below let it as old dict get method to handle custom fallback value
-                    base_url=config.get("site_url", __uri__),
-                ),
+                link=page_url_full,
                 title=page.title,
                 updated=page_dates[1],
-                url_comments=page_url_comments,
-                url_full=page_url_full,
+                # for later fetch
+                _mkdocs_page_ref=MkdocsPageSubset.from_page(page),
             )
         )
 
@@ -385,7 +382,7 @@ class GitRssPlugin(BasePlugin[RssPluginConfig]):
         self.feed_created.entries.extend(
             self.util.filter_pages(
                 pages=self.pages_to_filter,
-                attribute="created",
+                filter_attribute="created",
                 length=self.config.length,
             )
         )
@@ -394,30 +391,33 @@ class GitRssPlugin(BasePlugin[RssPluginConfig]):
         self.feed_updated.entries.extend(
             self.util.filter_pages(
                 pages=self.pages_to_filter,
-                attribute="updated",
+                filter_attribute="updated",
                 length=self.config.length,
             )
         )
 
+        # load RSS items images (enclosures)
+        logger.debug(
+            f"Loading images for {len(self.feed_created.entries)} pages by creation "
+            f"and {len(self.feed_updated.entries)} pages by update"
+        )
+        processed_refs = set()
+        self.util.load_images_for_pages(
+            self.feed_created.entries, config.site_url, processed_refs
+        )
+        self.util.load_images_for_pages(
+            self.feed_updated.entries, config.site_url, processed_refs
+        )
+
         # RSS
         if self.config.rss_feed_enabled:
-            # write feeds according to the pretty print option
+            # Jinja environment depending on the pretty print option
             if pretty_print:
                 # load Jinja environment and template
                 env = Environment(
                     autoescape=select_autoescape(["html", "xml"]),
                     loader=FileSystemLoader(self.tpl_folder),
                 )
-
-                template = env.get_template(self.tpl_file.name)
-
-                # write feeds to files
-                with out_feed_created.open(mode="w", encoding="UTF8") as fifeed_created:
-                    fifeed_created.write(template.render(feed=self.feed_created))
-
-                with out_feed_updated.open(mode="w", encoding="UTF8") as fifeed_updated:
-                    fifeed_updated.write(template.render(feed=self.feed_updated))
-
             else:
                 # load Jinja environment and template
                 env = Environment(
@@ -426,9 +426,19 @@ class GitRssPlugin(BasePlugin[RssPluginConfig]):
                     lstrip_blocks=True,
                     trim_blocks=True,
                 )
-                template = env.get_template(self.tpl_file.name)
-                # write feeds to files stripping out spaces and new lines
-                with out_feed_created.open(mode="w", encoding="UTF8") as fifeed_created:
+            template = env.get_template(self.tpl_file.name)
+
+            # -- Feed sorted by creation date
+            logger.debug("Fill creation dates and dump created feed into RSS template.")
+            # set pub date as created
+            for page in self.feed_created.entries:
+                page.pub_date = format_datetime(dt=page.created)
+
+            # write file
+            with out_feed_created.open(mode="w", encoding="UTF8") as fifeed_created:
+                if pretty_print:
+                    fifeed_created.write(template.render(feed=self.feed_created))
+                else:
                     prev_char = ""
                     for char in template.render(feed=asdict(self.feed_created)):
                         if char == "\n":
@@ -440,7 +450,18 @@ class GitRssPlugin(BasePlugin[RssPluginConfig]):
                         prev_char = char
                         fifeed_created.write(char)
 
-                with out_feed_updated.open(mode="w", encoding="UTF8") as fifeed_updated:
+            # -- Feed sorted by last update date
+            logger.debug("Fill update dates and dump udpated feed into RSS template.")
+            # set pub date as updated
+            for page in self.feed_updated.entries:
+                page.pub_date = format_datetime(dt=page.updated)
+
+            # write file
+            with out_feed_updated.open(mode="w", encoding="UTF8") as fifeed_updated:
+                if pretty_print:
+                    fifeed_updated.write(template.render(feed=self.feed_updated))
+                else:
+                    prev_char = ""
                     for char in template.render(feed=asdict(self.feed_updated)):
                         if char == "\n":
                             # convert new lines to spaces to preserve sentence structure
@@ -455,14 +476,14 @@ class GitRssPlugin(BasePlugin[RssPluginConfig]):
         if self.config.json_feed_enabled:
             with out_json_created.open(mode="w", encoding="UTF8") as fp:
                 json.dump(
-                    self.util.feed_to_json(asdict(self.feed_created)),
+                    self.util.feed_to_json(self.feed_created),
                     fp,
                     indent=4 if self.config.pretty_print else None,
                 )
 
             with out_json_updated.open(mode="w", encoding="UTF8") as fp:
                 json.dump(
-                    self.util.feed_to_json(asdict(self.feed_updated), updated=True),
+                    self.util.feed_to_json(self.feed_updated),
                     fp,
                     indent=4 if self.config.pretty_print else None,
                 )
